import {
  select, 
  csv, 
  scaleLinear, 
  max, 
  scaleBand, 
  axisLeft,
  axisBottom
} from 'd3';

const svg = d3.select('svg');
const w = +svg.attr('width');
const h = +svg.attr('height');

const render = data => {
  const xVal = d => d.population;
  const yVal = d => d.country;
  const margin = {top:20, right:20, bottom:20, left:75}
  const innerWidth = w - margin.left - margin.right;
  const innerHeight = h - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xVal)])
  	.range([0, innerWidth])
  
  const yScale = scaleBand()
  	.domain(data.map(yVal))
  	.range([0, innerHeight])
  	.padding(0.1)
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`)
	
   
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0,${innerHeight})`)

  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
    .attr( 'y', d => yScale(yVal(d)) )
  	.attr( 'width', d => xScale(xVal(d)) )
  	.attr( 'height', yScale.bandwidth() )
};

csv('data.csv').then(data => {
	data.forEach(d => {
  	d.population = +d.population
  })
  render(data)
})



